function [Tmse, Tcorr, Tpress] = KfoldCV(X, Y, k)
  warning off;
  CVO = cvpartition(Y,'k',k);
  fac = size(X,2);

  Tmse   = zeros(size(1, fac));
  Tcorr  = zeros(size(1, fac));
  Tpress = zeros(size(1, fac));
  
  TmseTemp   = zeros(size(fac, k));
  TcorrTemp  = zeros(size(fac, k));
  TpressTemp = zeros(size(fac, k));
  
  for i = 1:k
     
    trIdx  = CVO.training(i);
    teIdx  = CVO.test(i);
  
    dOutTe = Y(teIdx,:); 
    dInTe  = X(teIdx,:); 
    
    dOutTr = Y(trIdx,:); 
    dInTr  = X(trIdx,:); 
  
    [mcxcal,mxcal] = mncn(dInTr);                 %mean center cal X-block
    [mcycal,mycal] = mncn(dOutTr);                %mean center cal Y-block
    scxtest        = scale(dInTe,mxcal);          %center test X-block
    bpls           = simpls(mcxcal,mcycal,fac);   %obtain regression vector
    
    for j = 1:fac
        yppred          = rescale(scxtest*bpls(j,:)',mycal); %project and rescale predictions
        TmseTemp(j,i)   = mse(yppred - dOutTe);
        TcorrTemp(j,i)  = corr2(yppred, dOutTe);
        TpressTemp(j,i) = sum((yppred-dOutTe).^2);   
    end
   
  end

  for j = 1:fac
    Tmse(1,j)   = mean(TmseTemp(j,:)); 
    Tcorr(1,j)  = mean(TcorrTemp(j,:));
    Tpress(1,j) = mean(TpressTemp(j,:));
  end  
  
end